class Receta < ApplicationRecord
	has_many :pasos ,:dependent => :destroy , inverse_of: :receta
	has_many :ingredientes, :dependent => :destroy , inverse_of: :receta
	has_many :alimentos, :through => :ingredientes
	validates :dificultad, numericality: {only_integer: true,greater_than_or_equal_to: 1,less_than_or_equal_to: 3 }
	validates :tiempo, presence: true
	validates :nombre, presence: true
	validates :dificultad, presence: true
	validates :descripcion, presence: true

	accepts_nested_attributes_for :ingredientes, reject_if: :all_blank, allow_destroy: true
  accepts_nested_attributes_for :pasos, reject_if: :all_blank, allow_destroy: true

	def gluten
		ingredientes = self.alimentos

		ingredientes.each do |ingrediente|
			if ingrediente.gluten == 1
				return true
			end
		end
		false
	end

  def vegetariano
    ingredientes = self.alimentos
    ingredientes.each do |ingrediente|
      if ["Carnes y derivados","Mariscos y derivados","Pescados y derivados"].include?(ingrediente.grupo) || ["Manteca de cerdo"].include?(ingrediente.nombre)
        return false
      end
    end
    true
  end

  def vegano
    if vegetariano
      ingredientes = self.alimentos
      ingredientes.each do |ingrediente|
        if ["Huevos y derivados","Leches y derivados"].include?(ingrediente.grupo)  || ["Mantequilla"].include?(ingrediente.nombre)
          return false
        end
      end
      true
    else
      false
    end
  end 

	def kcal_racion
	      (kcal/raciones).round
	end

	def kcal
	    kcal = 0
		ingredientes = self.ingredientes
	    #Iteration through the ingredients
	    ingredientes.each do |ingrediente|
		          alimento = Alimento.find(ingrediente.alimento_id)
		          #Kcal conversion to the ingredient quantity
		          kcal_alimento = (alimento.energia.fdiv(100))*ingrediente.cantidad
		          kcal = kcal + kcal_alimento
		      end
		      #Recipe Kcal/portion round 
		      return kcal
	end

	def proteina
      proteina = 0
      ingredientes = self.ingredientes
      #Iteration through the ingredients
      ingredientes.each do |ingrediente|
          alimento = Alimento.find(ingrediente.alimento_id)
          #Protein conversion to ingredient quantity
          proteina_alimento = (alimento.proteina.fdiv(100))*ingrediente.cantidad
          proteina = proteina + proteina_alimento
      end
      #Protein per portion round
      return proteina
    end

    def proteina_racion
      (proteina/raciones).round
    end

    def hidratos
      hidratos = 0
      ingredientes = self.ingredientes
      #Iteration through the ingredients
      ingredientes.each do |ingrediente|
        alimento = Alimento.find(ingrediente.alimento_id)
        #Protein conversion to ingredient quantity
        hidratos_alimento = (alimento.glucidos.fdiv(100))*ingrediente.cantidad
        hidratos = hidratos + hidratos_alimento
      end
      #Protein per portion round
      return hidratos
    end

    def hidratos_racion
        (hidratos/raciones).round
    end

    def grasa
      grasa = 0
      ingredientes = self.ingredientes
      #Iteration through the ingredients
      ingredientes.each do |ingrediente|
          alimento = Alimento.find(ingrediente.alimento_id)
          #Protein conversion to ingredient quantity
          grasa_alimento = (alimento.lipidos.fdiv(100))*ingrediente.cantidad
          grasa = grasa + grasa_alimento
      end
      #Protein per portion round
      return grasa
    end

    def grasa_racion
      (grasa/raciones).round
    end
end


